@@ -155,6 +155,11 @@ private Q_SLOTS:
             {_("VOLKER KRAUSE"), _("Volker"), _("Krause")},
             {_("KRAUSE"),{}, {}}
         };
+
+        QTest::newRow("double given name") << QVector<QStringList> {
+            {_("Kai Uwe Broulik"), _("Kai Uwe"), _("Broulik")},
+            {_("Kai Broulik"), _("Kai"), _("Broulik")},
+        };
     }
 
     void testIsSamePerson()
@@ -240,6 +245,17 @@ private Q_SLOTS:
         QTest::newRow("number mismatch") << QString() << _("123") << QString() << _("234") << false;
         QTest::newRow("number prefix") << QString() << _("123") << QString() << _("12") << false;
         QTest::newRow("number prefix2") << QString() << _("123") << QString() << _("23") << false;
+
+        QTest::newRow("train-and-line-number-0") << QString() << _("RE 13 (20070)") << QString() << _("RE 13 (20072)") << false;
+        QTest::newRow("train-and-line-number-1") << QString() << _("RE 13 (20070)") << QString() << _("RE 20070") << true;
+        QTest::newRow("train-and-line-number-2") << QString() << _("RE 13 (20070)") << QString() << _("RE 13") << true;
+        //QTest::newRow("train-and-line-number-3") << QString() << _("RE 13 (20070)") << QString() << _("RE") <<  false;
+        QTest::newRow("train-and-line-number-4") << QString() << _("RB 33 (10323)") << QString() << _("RE 33") << false;
+        QTest::newRow("train-and-line-number-5") << QString() << _("RB 33 (10323)") << QString() << _("RE 10323") << false;
+        QTest::newRow("train-and-line-number-6") << QString() << _("RB 33 (10323)") << QString() << _("RB 10323") << true;
+        QTest::newRow("train-and-line-number-7") << QString() << _("RB 33 (10323)") << QString() << _("RB 33") << true;
+        QTest::newRow("train-and-line-number-8") << QString() << _("RB 33 (10323)") << QString() << _("RB 23") << false;
+        QTest::newRow("train-and-line-number-9") << QString() << _("RB 33 (10323)") << QString() << _("RB 23 (10323)") << false;
     }
 
     void testIsSameTrain()
@@ -328,6 +344,28 @@ private Q_SLOTS:
         }
         QCOMPARE(mergedJson, expected);
     }
+
+    void testIsSameIncidence()
+    {
+        const auto lhsFlight = JsonLdDocument::fromJson(QJsonDocument::fromJson(readFile(QLatin1String(SOURCE_DIR "/calendarhandlerdata/flight.json"))).array()).first().value<FlightReservation>();
+        auto rhsFlight = lhsFlight;
+        Person p = rhsFlight.underName().value<Person>();
+        p.setName(QLatin1String("Jane Doe"));
+        rhsFlight.setUnderName(p);
+        QVERIFY(!MergeUtil::isSame(lhsFlight, rhsFlight));
+        QVERIFY(MergeUtil::isSameIncidence(lhsFlight, rhsFlight));
+
+        const auto lhsHotel = JsonLdDocument::fromJson(QJsonDocument::fromJson(readFile(QLatin1String(SOURCE_DIR "/calendarhandlerdata/hotel.json"))).array()).first().value<LodgingReservation>();
+        auto rhsHotel = lhsHotel;
+        p = rhsHotel.underName().value<Person>();
+        p.setName(QLatin1String("Jane Doe"));
+        rhsHotel.setUnderName(p);
+        QVERIFY(!MergeUtil::isSame(lhsHotel, rhsHotel));
+        QVERIFY(MergeUtil::isSameIncidence(lhsHotel, rhsHotel));
+        rhsHotel.setCheckinTime(rhsHotel.checkoutTime().addDays(2));
+        QVERIFY(!MergeUtil::isSame(lhsHotel, rhsHotel));
+        QVERIFY(!MergeUtil::isSameIncidence(lhsHotel, rhsHotel));
+    }
 };
 
 QTEST_APPLESS_MAIN(MergeUtilTest)
