@@ -5,7 +5,6 @@
 */
 
 #include "barcode.h"
-#include <era/ssbticketreader.h>
 #include <pdf/pdfbarcodeutil_p.h>
 
 #include <KItinerary/PdfDocument>
@@ -20,7 +19,7 @@
 
 using namespace KItinerary;
 
-void JsApi::Barcode::setDecoder(BarcodeDecoder *decoder)
+void JsApi::Barcode::setDecoder(const BarcodeDecoder *decoder)
 {
     m_decoder = decoder;
 }
@@ -87,9 +86,4 @@ QString JsApi::Barcode::decodeBarcode(const QVariant &img, BarcodeDecoder::Barco
     return {};
 }
 
-QVariant JsApi::Barcode::decodeEraSsbTicket(const QByteArray &s, int versionOverride) const
-{
-    return SSBTicketReader::read(s, versionOverride);
-}
-
 #include "moc_barcode.cpp"
