@@ -9,6 +9,7 @@
 #include "airportdb_data.cpp"
 #include "airportnametokenizer_p.h"
 #include "stringutil.h"
+#include "timezonedb_p.h"
 
 #include <QDebug>
 #include <QTimeZone>
@@ -43,7 +44,7 @@ QTimeZone timezoneForAirport(IataCode iataCode)
         return {};
     }
 
-    return KnowledgeDb::timezoneForLocation((*it).coordinate.latitude, (*it).coordinate.longitude, (*it).country.toString());
+    return KnowledgeDb::timezoneForLocation((*it).coordinate.latitude, (*it).coordinate.longitude, (*it).country.toString(), {});
 }
 
 KnowledgeDb::CountryId countryForAirport(IataCode iataCode)
