@@ -8,6 +8,7 @@
 #include "logging.h"
 
 #include <cstdint>
+#include <cstring>
 
 using namespace KItinerary;
 
@@ -56,6 +57,11 @@ Uic9183Header::Uic9183Header(const QByteArray& data)
     m_data = data;
 }
 
+bool Uic9183Header::operator==(const Uic9183Header &other) const
+{
+    return isValid() && other.isValid() && std::memcmp(m_data.constData(), other.m_data.constData(), PrefixSize) == 0;
+}
+
 bool Uic9183Header::isValid() const
 {
     return !m_data.isEmpty();
