@@ -99,7 +99,7 @@ int Vendor0080BLSubBlock::contentSize() const
     if (isNull()) {
         return 0;
     }
-    return QByteArray(m_block.content() + m_offset + SBlockLengthOffset, SBlockLengthSize).toInt();
+    return Uic9183Utils::readAsciiEncodedNumber(m_block.content(), m_block.size(), m_offset + SBlockLengthOffset, SBlockLengthSize);
 }
 
 const char* Vendor0080BLSubBlock::id() const
@@ -233,7 +233,7 @@ Vendor0080BLSubBlock Vendor0080BLBlock::findSubBlock(const char id[3]) const
 
 QVariant Vendor0080BLBlock::findSubBlock(const QString &str) const
 {
-    if (str.size() != 3) {
+    if (str.size() != 3 || !isValid()) {
         return {};
     }
     const auto b = findSubBlock(str.toUtf8().constData());
